@@ -79,17 +79,24 @@ debug_dump_boxes (HtmlBox *root, gint indent, gboolean has_node, xmlNode *n)
 		g_print ("%s ", root->dom_node->xmlnode->name);
 	g_print ("\n");
 	if (HTML_IS_BOX_TEXT (root)) {
+		HtmlBoxText *box_text;
 		gint len;
-		gchar *text = html_box_text_get_text (HTML_BOX_TEXT (root), &len);
+		gchar *text;
+
+		box_text = HTML_BOX_TEXT (root);
+		text = html_box_text_get_text (box_text, &len);
+		g_print ("Master: %p forced_newline: %d\n", box_text->master, box_text->forced_newline);
   		if (len) {
                         gchar *buffer;
 
 			for (i = 0; i < indent; i++)
 				g_print (" ");
-			buffer = g_malloc (len + 2);
-			strncpy (buffer, text, len);
-			buffer[len] = '\n';
-			buffer[len + 1] = 0;
+			buffer = g_malloc (len + 4);
+			buffer[0] = '|';
+			strncpy (buffer + 1, text, len);
+			buffer[len + 1] = '|';
+			buffer[len + 2] = '\n';
+			buffer[len + 3] = 0;
 			g_print (buffer);
 			g_free (buffer);
 		}
@@ -298,7 +305,7 @@ get_link_index (HtmlBox *root, HtmlBox *link_box, gint *link_index)
 	gboolean ret;
 
 	if (!root)
-		return NULL;
+		return FALSE;
 
 	if (HTML_IS_BOX_INLINE (root)) {
 		if (root == link_box)
@@ -343,14 +350,20 @@ html_view_accessible_get_focus_object (GtkWidget *widget, gint *link_index)
 			}
 		}
 		g_assert (HTML_IS_BOX_BLOCK (box));
-
+		if (box->dom_node && strcmp ((char *)box->dom_node->xmlnode->name, "p") == 0) {
+			if (link_index) {
+				index = 0;
+				if (get_link_index (box, focus_box, &index))
+					*link_index = index;
+			}
+		} else {
+			box = focus_box->children;
+			if (link_index) {
+				*link_index = 0;
+			}
+		}
 		g_object_set_data (G_OBJECT (box), "view", widget);
 		atk_obj = atk_gobject_accessible_for_object (G_OBJECT (box));
-		if (link_index) {
-			index = 0;
-			if (get_link_index (box, focus_box, &index))
-				*link_index = index;
-		}
 	} else {
 		atk_obj = NULL;
 	}
