@@ -48,7 +48,7 @@ struct _HtmlBoxTextMaster {
 	guint must_relayout : 1;
 	guint preserved_leading_space : 1;
 	HtmlFontSpecification *font_spec;
-	HtmlWhiteSpaceType white_space:2;
+	guint white_space:2;
 };
 
 struct _HtmlBoxTextItemData {
@@ -736,7 +736,7 @@ html_box_text_get_len (HtmlBoxText *box)
 gchar *
 html_box_text_get_text (HtmlBoxText *box, int *text_len)
 {
-	g_return_if_fail (box != NULL);
+	g_return_val_if_fail (box != NULL, NULL);
 
 	if (text_len)
 		*text_len = box->length;
