@@ -1407,10 +1407,15 @@ move_cursor (HtmlView *view, HtmlBox *new_cursor_box, gint offset, gboolean exte
 			DomElement *element;
 
 			element = DOM_ELEMENT (new_cursor_box->parent->dom_node);
-			if (dom_element_is_focusable (element) &&
-			    element != view->document->focus_element) {
-                		html_document_update_focus_element (view->document, element);
-                		html_view_focus_element (view);
+			if (dom_element_is_focusable (element)) {
+			
+				if (element != view->document->focus_element) {
+                			html_document_update_focus_element (view->document, element);
+                			html_view_focus_element (view);
+				}
+			} else if (view->document->focus_element) {
+				html_document_update_focus_element (view->document, NULL);
+				html_view_focus_element (view);
 			}
 		}
 	}
@@ -2452,6 +2457,9 @@ html_view_finalize (GObject *object)
 	if (layout)
 		g_object_unref (layout);	
 
+	if (view->jump_to_anchor)
+		g_free (view->jump_to_anchor);
+		
 	if (G_OBJECT_CLASS (parent_class)->finalize)
 		(G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
@@ -3240,7 +3248,9 @@ html_view_focus_element (HtmlView *view)
 		/* No element focused to scroll to top */
 		GtkAdjustment *adj = GTK_LAYOUT (view)->vadjustment;
 
-		set_adjustment_clamped (adj, 0);
+		if (!html_view_get_cursor_visible (view)) {
+			set_adjustment_clamped (adj, 0);
+		}
 		gtk_widget_grab_focus (GTK_WIDGET (view));
 	}
 	gtk_widget_queue_draw (GTK_WIDGET (view));
